# Legit Indicators

![Publish Python 🐍 distributions 📦 to PyPI and TestPyPI](https://github.com/aticio/legitindicators/workflows/Publish%20Python%20%F0%9F%90%8D%20distributions%20%F0%9F%93%A6%20to%20PyPI%20and%20TestPyPI/badge.svg)

Collection of indicators that I used in my strategies.

## Installation

Run the following to install:

```python
pip install legitindicators
```
